@@ -9,9 +9,11 @@ with warnings.catch_warnings():
     from future import standard_library
 standard_library.install_aliases()
 from builtins import object
-import io
 import json
+from typing import Any
+from typing import AnyStr
 from typing import Dict
+from typing import IO
 from typing import List
 from typing import Optional
 from typing import Union
@@ -26,7 +28,7 @@ from .utils import encode
 if BUILD_GCLOUD_REST:
     from requests import Session
 else:
-    from aiohttp import ClientSession as Session
+    from aiohttp import ClientSession as Session  # type: ignore[no-redef]
 
 API_ROOT_IAM = 'https://iam.googleapis.com/v1'
 API_ROOT_IAM_CREDENTIALS = 'https://iamcredentials.googleapis.com/v1'
@@ -34,7 +36,7 @@ SCOPES = ['https://www.googleapis.com/auth/iam']
 
 
 class IamClient(object):
-    def __init__(self, service_file                                  = None,
+    def __init__(self, service_file                                   = None,
                  session                    = None,
                  token                  = None)        :
         self.session = SyncSession(session)
@@ -81,7 +83,8 @@ class IamClient(object):
 
         resp = s.get(url=url, headers=headers, timeout=timeout)
 
-        return resp.json()
+        data                 = resp.json()
+        return data
 
     # https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts.keys/list
     def list_public_keys(
@@ -102,12 +105,13 @@ class IamClient(object):
 
         resp = s.get(url=url, headers=headers, timeout=timeout)
 
-        return (resp.json()).get('keys', [])
+        data                       = (resp.json()).get('keys', [])
+        return data
 
     # https://cloud.google.com/iam/credentials/reference/rest/v1/projects.serviceAccounts/signBlob
     def sign_blob(self, payload                             ,
                         service_account_email                = None,
-                        delegates                 = None,
+                        delegates                      = None,
                         session                    = None,
                         timeout      = 10)                  :
         service_account_email = (service_account_email or
@@ -121,7 +125,7 @@ class IamClient(object):
 
         json_str = json.dumps({
             'delegates': delegates or [resource_name],
-            'payload': encode(payload).decode('utf-8'),
+            'payload': encode(payload or '').decode('utf-8'),
         })
 
         headers = self.headers()
@@ -134,13 +138,14 @@ class IamClient(object):
 
         resp = s.post(url=url, data=json_str, headers=headers,
                             timeout=timeout)
-        return resp.json()
+        data                 = resp.json()
+        return data
 
-    def close(self):
+    def close(self)        :
         self.session.close()
 
     def __enter__(self)               :
         return self
 
-    def __exit__(self, *args)        :
+    def __exit__(self, *args     )        :
         self.close()
