@@ -13,12 +13,21 @@ import threading
 from abc import ABCMeta
 from abc import abstractmethod
 from abc import abstractproperty
-from io import IOBase
 from typing import Any
 from typing import Dict
+from typing import IO
+from typing import Optional
 
 from .build_constants import BUILD_GCLOUD_REST
 
+# Selectively load libraries based on the package
+if BUILD_GCLOUD_REST:
+    from requests import Response
+    from requests import Session
+else:
+    from aiohttp import ClientResponse as Response  # type: ignore[no-redef]
+    from aiohttp import ClientSession as Session  # type: ignore[no-redef]
+
 
 log = logging.getLogger(__name__)
 
@@ -26,39 +35,41 @@ log = logging.getLogger(__name__)
 class BaseSession(object):
     __metaclass__ = ABCMeta
 
-    def __init__(self, session=None, timeout      = 10,
-                 verify_ssl       = True):
+    def __init__(self, session                    = None, timeout      = 10,
+                 verify_ssl       = True)        :
         self._session = session
         self._ssl = verify_ssl
         self._timeout = timeout
 
     @abstractproperty
-    def session(self):
+    def session(self)                     :
         return self._session
 
     @abstractmethod
-    def post(self, url     , headers                , data     , timeout     ,
-             params                ):
+    def post(self, url     , headers                ,
+                   data               , timeout     ,
+                   params                          )            :
         pass
 
     @abstractmethod
-    def get(self, url     , headers                , timeout     ,
-            params                ):
+    def get(self, url     , headers                          ,
+                  timeout     , params                          )            :
         pass
 
     @abstractmethod
-    def put(self, url     , headers                , data        ,
-            timeout     ):
+    def put(self, url     , headers                , data         ,
+                  timeout     )            :
         pass
 
     @abstractmethod
-    def delete(self, url     , headers                , params                ,
-               timeout     ):
+    def delete(self, url     , headers                ,
+                     params                , timeout     )            :
         pass
 
     @abstractmethod
     def request(self, method     , url     , headers                ,
-                auto_raise_for_status       = True, **kwargs     ):
+                      auto_raise_for_status       = True,
+                      **kwargs     )            :
         pass
 
     @abstractmethod
@@ -107,23 +118,24 @@ if not BUILD_GCLOUD_REST:
             return self._session
 
         def post(self, url     , headers                ,
-                       data      = None, timeout      = 10,
-                       params                 = None
+                       data                = None, timeout      = 10,
+                       params                           = None
                        )                          :
             resp = self.session.post(url, data=data, headers=headers,
                                            timeout=timeout, params=params)
             _raise_for_status(resp)
             return resp
 
-        def get(self, url     , headers                 = None,
-                      timeout      = 10, params                 = None
+        def get(self, url     , headers                           = None,
+                      timeout      = 10,
+                      params                           = None
                       )                          :
             resp = self.session.get(url, headers=headers, timeout=timeout,
                                           params=params)
             _raise_for_status(resp)
             return resp
 
-        def put(self, url     , headers                , data        ,
+        def put(self, url     , headers                , data         ,
                       timeout      = 10)                          :
             resp = self.session.put(url, data=data, headers=headers,
                                           timeout=timeout)
@@ -131,7 +143,8 @@ if not BUILD_GCLOUD_REST:
             return resp
 
         def delete(self, url     , headers                ,
-                         params                , timeout      = 10
+                         params                           = None,
+                         timeout      = 10
                          )                          :
             resp = self.session.delete(url, headers=headers,
                                              params=params, timeout=timeout)
@@ -149,12 +162,10 @@ if not BUILD_GCLOUD_REST:
 
         def close(self)        :
             if self._session:
-                self._session.close()
+                self._session.close()  # type: ignore[func-returns-value]
 
 
 if BUILD_GCLOUD_REST:
-    import requests
-
     class SyncSession(BaseSession):
         _google_api_lock = threading.RLock()
 
@@ -163,31 +174,34 @@ if BUILD_GCLOUD_REST:
             return SyncSession._google_api_lock  # pylint: disable=protected-access
 
         @property
-        def session(self)                    :
-            self._session = self._session or requests.Session()
+        def session(self)           :
+            self._session = self._session or Session()
             self._session.verify = self._ssl
             return self._session
 
-        def post(self, url     , headers                , data      = None,
-                 timeout      = 10, params                 = None
-                 )                     :
+        # N.B.: none of these will be `async` in compiled form, but adding the
+        # symbol ensures we match the base class's definition for static
+        # analysis.
+        def post(self, url     , headers                ,
+                       data                = None, timeout      = 10,
+                       params                           = None)            :
             with self.google_api_lock:
                 resp = self.session.post(url, data=data, headers=headers,
                                          timeout=timeout, params=params)
             resp.raise_for_status()
             return resp
 
-        def get(self, url     , headers                 = None,
-                timeout      = 10, params                 = None
-                )                     :
+        def get(self, url     , headers                           = None,
+                      timeout      = 10,
+                      params                           = None)            :
             with self.google_api_lock:
                 resp = self.session.get(url, headers=headers, timeout=timeout,
                                         params=params)
             resp.raise_for_status()
             return resp
 
-        def put(self, url     , headers                , data        ,
-                timeout      = 10)                     :
+        def put(self, url     , headers                , data         ,
+                      timeout      = 10)            :
             with self.google_api_lock:
                 resp = self.session.put(url, data=data, headers=headers,
                                         timeout=timeout)
@@ -195,8 +209,9 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def delete(self, url     , headers                ,
-                   params                , timeout      = 10
-                   )                     :
+                         params                           = None,
+                         timeout      = 10
+                         )            :
             with self.google_api_lock:
                 resp = self.session.delete(url, params=params, headers=headers,
                                            timeout=timeout)
@@ -204,8 +219,8 @@ if BUILD_GCLOUD_REST:
             return resp
 
         def request(self, method     , url     , headers                ,
-                    auto_raise_for_status       = True, **kwargs     
-                    )                     :
+                          auto_raise_for_status       = True, **kwargs     
+                          )            :
             with self.google_api_lock:
                 resp = self.session.request(method, url, headers=headers,
                                             **kwargs)
