@@ -16,12 +16,13 @@ with warnings.catch_warnings():
 standard_library.install_aliases()
 import datetime
 import enum
-import io
 import json
 import os
 import time
 from typing import Any
+from typing import AnyStr
 from typing import Dict
+from typing import IO
 from typing import List
 from typing import Optional
 from typing import Union
@@ -41,16 +42,19 @@ from .session import SyncSession
 
 # Handle differences in exceptions
 try:
-    CustomFileError = FileNotFoundError
+    # TODO: Type[Exception] should work here, no?
+    CustomFileError      = FileNotFoundError
 except NameError:
     CustomFileError = IOError
 
 
 # Selectively load libraries based on the package
 if BUILD_GCLOUD_REST:
+    from requests import Response
     from requests import Session
 else:
-    from aiohttp import ClientSession as Session
+    from aiohttp import ClientResponse as Response  # type: ignore[no-redef]
+    from aiohttp import ClientSession as Session  # type: ignore[no-redef]
     import asyncio
 
 GCE_METADATA_BASE = 'http://metadata.google.internal/computeMetadata/v1'
@@ -69,7 +73,7 @@ class Type(enum.Enum):
 
 
 def get_service_data(
-        service                                 )                  :
+        service                                  )                  :
     service = service or os.environ.get('GOOGLE_APPLICATION_CREDENTIALS')
     if not service:
         cloudsdk_config = os.environ.get('CLOUDSDK_CONFIG')
@@ -83,11 +87,11 @@ def get_service_data(
 
     try:
         try:
-            with open(service, 'r') as f:
+            with open(service, 'r') as f:  # type: ignore[arg-type]
                 data                 = json.loads(f.read())
                 return data
         except TypeError:
-            data                 = json.loads(service.read())
+            data = json.loads(service.read())  # type: ignore[union-attr]
             return data
     except CustomFileError:
         if set_explicitly:
@@ -101,9 +105,9 @@ def get_service_data(
 
 class Token(object):
     # pylint: disable=too-many-instance-attributes
-    def __init__(self, service_file                                  = None,
+    def __init__(self, service_file                                   = None,
                  session                    = None,
-                 scopes            = None)        :
+                 scopes                      = None)        :
         self.service_data = get_service_data(service_file)
         if self.service_data:
             self.token_type = Type(self.service_data['type'])
@@ -125,7 +129,7 @@ class Token(object):
         self.access_token_duration = 0
         self.access_token_acquired_at = datetime.datetime(1970, 1, 1)
 
-        self.acquiring                           = None
+        self.acquiring                                = None
 
     def get_project(self)                 :
         project = (os.environ.get('GOOGLE_CLOUD_PROJECT')
@@ -170,8 +174,7 @@ class Token(object):
         self.acquiring = (self.acquire_access_token())
         self.acquiring
 
-    def _refresh_authorized_user(self,
-                                       timeout     )                  :
+    def _refresh_authorized_user(self, timeout     )            :
         payload = urlencode({
             'grant_type': 'refresh_token',
             'client_id': self.service_data['client_id'],
@@ -179,18 +182,19 @@ class Token(object):
             'refresh_token': self.service_data['refresh_token'],
         })
 
-        return self.session.post(url=self.token_uri, data=payload,
-                                       headers=REFRESH_HEADERS,
-                                       timeout=timeout)
+        data           = self.session.post(url=self.token_uri,
+                                                 data=payload,
+                                                 headers=REFRESH_HEADERS,
+                                                 timeout=timeout)
+        return data
 
-    def _refresh_gce_metadata(self,
-                                    timeout     )                  :
-        return self.session.get(url=self.token_uri,
-                                      headers=GCE_METADATA_HEADERS,
-                                      timeout=timeout)
+    def _refresh_gce_metadata(self, timeout     )            :
+        resp           = self.session.get(url=self.token_uri,
+                                                headers=GCE_METADATA_HEADERS,
+                                                timeout=timeout)
+        return resp
 
-    def _refresh_service_account(self,
-                                       timeout     )                  :
+    def _refresh_service_account(self, timeout     )            :
         now = int(time.time())
         assertion_payload = {
             'aud': self.token_uri,
@@ -209,9 +213,10 @@ class Token(object):
             'grant_type': 'urn:ietf:params:oauth:grant-type:jwt-bearer',
         })
 
-        return self.session.post(self.token_uri, data=payload,
-                                       headers=REFRESH_HEADERS,
-                                       timeout=timeout)
+        resp           = self.session.post(self.token_uri, data=payload,
+                                                 headers=REFRESH_HEADERS,
+                                                 timeout=timeout)
+        return resp
 
     @backoff.on_exception(backoff.expo, Exception, max_tries=5)  # type: ignore
     def acquire_access_token(self, timeout      = 10)        :
@@ -231,11 +236,11 @@ class Token(object):
         self.access_token_acquired_at = datetime.datetime.utcnow()
         self.acquiring = None
 
-    def close(self):
+    def close(self)        :
         self.session.close()
 
     def __enter__(self)           :
         return self
 
-    def __exit__(self, *args)        :
+    def __exit__(self, *args     )        :
         self.close()
